@@ -69,7 +69,7 @@ class CommandContext:
         return message_body
 
     
-    async def follwup(self, content: str = '', embeds: list[Embed] | Embed = [], components: list[ActionRow] | ActionRow = [], ephemeral: bool = False):
+    async def followup(self, content: str = '', embeds: list[Embed] | Embed = [], components: list[ActionRow] | ActionRow = [], ephemeral: bool = False):
         """
             Used to create a follow up response to an already acked interaction.
             Parameters
